bleach: An HTML-sanitizing tool
===============================

Description
-----------

An easy safelist-based HTML-sanitizing tool.

License
-------

Apache License v2


Upstream Contact
----------------

Home Page: https://github.com/mozilla/bleach
